==> plasma_2.5.1.tar.gz: plasma_2.5.1/docs/doxygen/out/html/group__float.js <==
var group__float =
[
    [ "PLASMA_sgebrd", "group__float_ga5a8eb1ec5b7f9a24c45ad5250100c4d5.html#ga5a8eb1ec5b7f9a24c45ad5250100c4d5", null ],
    [ "PLASMA_sgecon", "group__float_ga23012d51cf74d10f924e8dad2d56ba52.html#ga23012d51cf74d10f924e8dad2d56ba52", null ],
    [ "PLASMA_sgelqf", "group__float_gaecbccf81ab27bc4a0a5913baedf3b7ef.html#gaecbccf81ab27bc4a0a5913baedf3b7ef", null ],
    [ "PLASMA_sgelqs", "group__float_ga4bde040498b35dcbc88268de59de7d12.html#ga4bde040498b35dcbc88268de59de7d12", null ],
    [ "PLASMA_sgels", "group__float_ga2bbab59e86acca698a73c5bc8023e5c3.html#ga2bbab59e86acca698a73c5bc8023e5c3", null ],
    [ "PLASMA_sgemm", "group__float_gace4e6452ba3ffb8cef11be1987091382.html#gace4e6452ba3ffb8cef11be1987091382", null ],
    [ "PLASMA_sgeqp3", "group__float_ga06922daf59255d12c1fc228cecd6aaa0.html#ga06922daf59255d12c1fc228cecd6aaa0", null ],
    [ "PLASMA_sgeqrf", "group__float_gad2dff40bb75ba6ee7a91306e0a3e889e.html#gad2dff40bb75ba6ee7a91306e0a3e889e", null ],
    [ "PLASMA_sgeqrs", "group__float_ga15cad3c163c8d1137d13d66594652b7d.html#ga15cad3c163c8d1137d13d66594652b7d", null ],
    [ "PLASMA_sgesdd", "group__float_gad5f1778952268ef575d41e6bfcc7c7b4.html#gad5f1778952268ef575d41e6bfcc7c7b4", null ],
    [ "PLASMA_sgesv", "group__float_ga39018420f926f77ef11c50c82f66da77.html#ga39018420f926f77ef11c50c82f66da77", null ],
    [ "PLASMA_sgesv_incpiv", "group__float_gab9dab6c3f22b6cf8dad0fa2f1b563988.html#gab9dab6c3f22b6cf8dad0fa2f1b563988", null ],
    [ "PLASMA_sgesvd", "group__float_gabaf1acf98c5bbd242f4e603c2bbfffb1.html#gabaf1acf98c5bbd242f4e603c2bbfffb1", null ],
    [ "PLASMA_sgetrf", "group__float_ga8bf6af99c20539f64fa60b64d99fc1be.html#ga8bf6af99c20539f64fa60b64d99fc1be", null ],
    [ "PLASMA_sgetrf_incpiv", "group__float_ga2980cac88a14ba51d0ef99036f5ace69.html#ga2980cac88a14ba51d0ef99036f5ace69", null ],
    [ "PLASMA_sgetrf_nopiv", "group__float_ga1c9ced92c5818ef3a6af88e6545ba1e6.html#ga1c9ced92c5818ef3a6af88e6545ba1e6", null ],
    [ "PLASMA_sgetrf_tntpiv", "group__float_ga4a519bbf13b7a335ca2dd079693f9edc.html#ga4a519bbf13b7a335ca2dd079693f9edc", null ],
    [ "PLASMA_sgetri", "group__float_gadb78715cdd99791aa77c2640f1325f8e.html#gadb78715cdd99791aa77c2640f1325f8e", null ],
    [ "PLASMA_sgetrs", "group__float_ga655cb742ac1c78e5ce86070f4ce1271b.html#ga655cb742ac1c78e5ce86070f4ce1271b", null ],
    [ "PLASMA_sgetrs_incpiv", "group__float_gae593ed2d7e164acc75c4e6efdca4d95a.html#gae593ed2d7e164acc75c4e6efdca4d95a", null ],
    [ "PLASMA_slacpy", "group__float_ga2ae5e8cc7cf6222bf521a6decd6c27a1.html#ga2ae5e8cc7cf6222bf521a6decd6c27a1", null ],
    [ "PLASMA_slange", "group__float_gaf12ff85306bc548593674ce694d5e5be.html#gaf12ff85306bc548593674ce694d5e5be", null ],
    [ "PLASMA_slansy", "group__float_gaad7d8cac5c5334f8cc144f36050bbdc3.html#gaad7d8cac5c5334f8cc144f36050bbdc3", null ],
    [ "PLASMA_sLapack_to_Tile", "group__float_gaad3dd3212d3d774f44094c3f0835ef22.html#gaad3dd3212d3d774f44094c3f0835ef22", null ],
    [ "PLASMA_slaset", "group__float_gaeb7486c1cb46dd4a81c11981605c093c.html#gaeb7486c1cb46dd4a81c11981605c093c", null ],
    [ "PLASMA_slaswp", "group__float_gaa20663314d5fd0c31c8a8a2fd6efc7e5.html#gaa20663314d5fd0c31c8a8a2fd6efc7e5", null ],
    [ "PLASMA_slaswpc", "group__float_ga044b505b0a887de1be5636328ebe60ab.html#ga044b505b0a887de1be5636328ebe60ab", null ],
    [ "PLASMA_slauum", "group__float_gaafb49f230a9c4dbdc635144f46f680f6.html#gaafb49f230a9c4dbdc635144f46f680f6", null ],
    [ "PLASMA_sorglq", "group__float_ga2f8b6c06f4346761e024c9fa00427a61.html#ga2f8b6c06f4346761e024c9fa00427a61", null ],
    [ "PLASMA_sorgqr", "group__float_ga4b6a6aa9e5da7961424f3afb62a69562.html#ga4b6a6aa9e5da7961424f3afb62a69562", null ],
    [ "PLASMA_sormlq", "group__float_ga4f42eb41e34bdf290b36fe5ce8e576b7.html#ga4f42eb41e34bdf290b36fe5ce8e576b7", null ],
    [ "PLASMA_sormqr", "group__float_ga3d2c263d860db4a6d63fd13156262bd2.html#ga3d2c263d860db4a6d63fd13156262bd2", null ],
    [ "PLASMA_splgsy", "group__float_ga949e065a6843e3d20ebc74741ccec2e2.html#ga949e065a6843e3d20ebc74741ccec2e2", null ],
    [ "PLASMA_splrnt", "group__float_ga1ab9b8f017c16245b0f44ab6f4798dfd.html#ga1ab9b8f017c16245b0f44ab6f4798dfd", null ],
    [ "PLASMA_spocon", "group__float_gae4ca020dbb8fa3516e2e4c89a6b60b1a.html#gae4ca020dbb8fa3516e2e4c89a6b60b1a", null ],
    [ "PLASMA_sposv", "group__float_ga113c09b4a9f41fc4c19358a52477d685.html#ga113c09b4a9f41fc4c19358a52477d685", null ],
    [ "PLASMA_spotrf", "group__float_ga3ada27ebefe8e378bc6f9d25ab72d217.html#ga3ada27ebefe8e378bc6f9d25ab72d217", null ],
    [ "PLASMA_spotri", "group__float_gaf35cf8d73bf326a683f4be4943ef9b38.html#gaf35cf8d73bf326a683f4be4943ef9b38", null ],
    [ "PLASMA_spotrs", "group__float_gab813bd6d81c21feae7ce6553c9ba255a.html#gab813bd6d81c21feae7ce6553c9ba255a", null ],
    [ "PLASMA_ssyev", "group__float_ga92b57475b852b71b42bc39cd0d1ec356.html#ga92b57475b852b71b42bc39cd0d1ec356", null ],
    [ "PLASMA_ssyevd", "group__float_ga71305bb114c063946ddd9003bea058bf.html#ga71305bb114c063946ddd9003bea058bf", null ],
    [ "PLASMA_ssyevr", "group__float_ga850dfaa20a85559bd1ef0042e4218ecd.html#ga850dfaa20a85559bd1ef0042e4218ecd", null ],
    [ "PLASMA_ssygst", "group__float_ga66b77c0de44f80760c4184756250e75e.html#ga66b77c0de44f80760c4184756250e75e", null ],
    [ "PLASMA_ssygv", "group__float_gaa5deb8e85d037eff767d9a9e5e99fad9.html#gaa5deb8e85d037eff767d9a9e5e99fad9", null ],
    [ "PLASMA_ssygvd", "group__float_ga366bd2466847e2b9f29bd39a9d699fb9.html#ga366bd2466847e2b9f29bd39a9d699fb9", null ],
    [ "PLASMA_ssymm", "group__float_gaaffcd386f207f3e3a3073a803e27e3f1.html#gaaffcd386f207f3e3a3073a803e27e3f1", null ],
    [ "PLASMA_ssyr2k", "group__float_gafac964a38a7c62696c3b95d35108ad9b.html#gafac964a38a7c62696c3b95d35108ad9b", null ],
    [ "PLASMA_ssyrk", "group__float_gae83f0347570d23dc62dd8b298eb14ad6.html#gae83f0347570d23dc62dd8b298eb14ad6", null ],
    [ "PLASMA_ssytrd", "group__float_gadfee26871dee9a24b201bc329fccd81b.html#gadfee26871dee9a24b201bc329fccd81b", null ],
    [ "PLASMA_sTile_to_Lapack", "group__float_gacfc6859eb0da6e5c246a70178b5567be.html#gacfc6859eb0da6e5c246a70178b5567be", null ],
    [ "PLASMA_strmm", "group__float_gabbc2cf7c018815bd2c1ce8a6623b2813.html#gabbc2cf7c018815bd2c1ce8a6623b2813", null ],
    [ "PLASMA_strsm", "group__float_ga572e80d04d4e9701bf3dd73d1f96d54c.html#ga572e80d04d4e9701bf3dd73d1f96d54c", null ],
    [ "PLASMA_strsmpl", "group__float_ga245da4f8540c426fde27a50eff39b64a.html#ga245da4f8540c426fde27a50eff39b64a", null ],
    [ "PLASMA_strsmrv", "group__float_ga7713151eac0c0ff54c5a6aac1957b5e0.html#ga7713151eac0c0ff54c5a6aac1957b5e0", null ],
    [ "PLASMA_strtri", "group__float_gaaf0df7b8ff03a270a25da71b9f133abb.html#gaaf0df7b8ff03a270a25da71b9f133abb", null ]
];

==> plasma_2.7.0.tar.gz: plasma_2.7.0/docs/doxygen/out/html/group__float.js <==
var group__float =
[
    [ "PLASMA_sgebrd", "group__float_ga5a8eb1ec5b7f9a24c45ad5250100c4d5.html#ga5a8eb1ec5b7f9a24c45ad5250100c4d5", null ],
    [ "PLASMA_sgecon", "group__float_ga23012d51cf74d10f924e8dad2d56ba52.html#ga23012d51cf74d10f924e8dad2d56ba52", null ],
    [ "PLASMA_sgelqf", "group__float_gaecbccf81ab27bc4a0a5913baedf3b7ef.html#gaecbccf81ab27bc4a0a5913baedf3b7ef", null ],
    [ "PLASMA_sgelqs", "group__float_ga4bde040498b35dcbc88268de59de7d12.html#ga4bde040498b35dcbc88268de59de7d12", null ],
    [ "PLASMA_sgels", "group__float_ga2bbab59e86acca698a73c5bc8023e5c3.html#ga2bbab59e86acca698a73c5bc8023e5c3", null ],
    [ "PLASMA_sgemm", "group__float_gace4e6452ba3ffb8cef11be1987091382.html#gace4e6452ba3ffb8cef11be1987091382", null ],
    [ "PLASMA_sgeqp3", "group__float_ga06922daf59255d12c1fc228cecd6aaa0.html#ga06922daf59255d12c1fc228cecd6aaa0", null ],
    [ "PLASMA_sgeqrf", "group__float_gad2dff40bb75ba6ee7a91306e0a3e889e.html#gad2dff40bb75ba6ee7a91306e0a3e889e", null ],
    [ "PLASMA_sgeqrs", "group__float_ga15cad3c163c8d1137d13d66594652b7d.html#ga15cad3c163c8d1137d13d66594652b7d", null ],
    [ "PLASMA_sgesdd", "group__float_gad5f1778952268ef575d41e6bfcc7c7b4.html#gad5f1778952268ef575d41e6bfcc7c7b4", null ],
    [ "PLASMA_sgesv", "group__float_ga39018420f926f77ef11c50c82f66da77.html#ga39018420f926f77ef11c50c82f66da77", null ],
    [ "PLASMA_sgesv_incpiv", "group__float_gab9dab6c3f22b6cf8dad0fa2f1b563988.html#gab9dab6c3f22b6cf8dad0fa2f1b563988", null ],
    [ "PLASMA_sgesvd", "group__float_gabaf1acf98c5bbd242f4e603c2bbfffb1.html#gabaf1acf98c5bbd242f4e603c2bbfffb1", null ],
    [ "PLASMA_sgetrf", "group__float_ga8bf6af99c20539f64fa60b64d99fc1be.html#ga8bf6af99c20539f64fa60b64d99fc1be", null ],
    [ "PLASMA_sgetrf_incpiv", "group__float_ga2980cac88a14ba51d0ef99036f5ace69.html#ga2980cac88a14ba51d0ef99036f5ace69", null ],
    [ "PLASMA_sgetrf_nopiv", "group__float_ga1c9ced92c5818ef3a6af88e6545ba1e6.html#ga1c9ced92c5818ef3a6af88e6545ba1e6", null ],
    [ "PLASMA_sgetrf_tntpiv", "group__float_ga4a519bbf13b7a335ca2dd079693f9edc.html#ga4a519bbf13b7a335ca2dd079693f9edc", null ],
    [ "PLASMA_sgetri", "group__float_gadb78715cdd99791aa77c2640f1325f8e.html#gadb78715cdd99791aa77c2640f1325f8e", null ],
    [ "PLASMA_sgetrs", "group__float_ga655cb742ac1c78e5ce86070f4ce1271b.html#ga655cb742ac1c78e5ce86070f4ce1271b", null ],
    [ "PLASMA_sgetrs_incpiv", "group__float_gae593ed2d7e164acc75c4e6efdca4d95a.html#gae593ed2d7e164acc75c4e6efdca4d95a", null ],
    [ "PLASMA_slacpy", "group__float_ga2ae5e8cc7cf6222bf521a6decd6c27a1.html#ga2ae5e8cc7cf6222bf521a6decd6c27a1", null ],
    [ "PLASMA_slange", "group__float_gaf12ff85306bc548593674ce694d5e5be.html#gaf12ff85306bc548593674ce694d5e5be", null ],
    [ "PLASMA_slansy", "group__float_gaad7d8cac5c5334f8cc144f36050bbdc3.html#gaad7d8cac5c5334f8cc144f36050bbdc3", null ],
    [ "PLASMA_slantr", "group__float_gac89a3f7eb1600d358791d38d2e662cb1.html#gac89a3f7eb1600d358791d38d2e662cb1", null ],
    [ "PLASMA_sLapack_to_Tile", "group__float_gaad3dd3212d3d774f44094c3f0835ef22.html#gaad3dd3212d3d774f44094c3f0835ef22", null ],
    [ "PLASMA_slaset", "group__float_gaeb7486c1cb46dd4a81c11981605c093c.html#gaeb7486c1cb46dd4a81c11981605c093c", null ],
    [ "PLASMA_slaswp", "group__float_gaa20663314d5fd0c31c8a8a2fd6efc7e5.html#gaa20663314d5fd0c31c8a8a2fd6efc7e5", null ],
    [ "PLASMA_slaswpc", "group__float_ga044b505b0a887de1be5636328ebe60ab.html#ga044b505b0a887de1be5636328ebe60ab", null ],
    [ "PLASMA_slauum", "group__float_gaafb49f230a9c4dbdc635144f46f680f6.html#gaafb49f230a9c4dbdc635144f46f680f6", null ],
    [ "PLASMA_sorglq", "group__float_ga2f8b6c06f4346761e024c9fa00427a61.html#ga2f8b6c06f4346761e024c9fa00427a61", null ],
    [ "PLASMA_sorgqr", "group__float_ga4b6a6aa9e5da7961424f3afb62a69562.html#ga4b6a6aa9e5da7961424f3afb62a69562", null ],
    [ "PLASMA_sormlq", "group__float_ga4f42eb41e34bdf290b36fe5ce8e576b7.html#ga4f42eb41e34bdf290b36fe5ce8e576b7", null ],
    [ "PLASMA_sormqr", "group__float_ga3d2c263d860db4a6d63fd13156262bd2.html#ga3d2c263d860db4a6d63fd13156262bd2", null ],
    [ "PLASMA_splgsy", "group__float_ga949e065a6843e3d20ebc74741ccec2e2.html#ga949e065a6843e3d20ebc74741ccec2e2", null ],
    [ "PLASMA_splrnt", "group__float_ga1ab9b8f017c16245b0f44ab6f4798dfd.html#ga1ab9b8f017c16245b0f44ab6f4798dfd", null ],
    [ "PLASMA_spltmg", "group__float_gaf78afc5a8cd9c1f43eb9cfecd9c0f7a1.html#gaf78afc5a8cd9c1f43eb9cfecd9c0f7a1", null ],
    [ "PLASMA_spocon", "group__float_gae4ca020dbb8fa3516e2e4c89a6b60b1a.html#gae4ca020dbb8fa3516e2e4c89a6b60b1a", null ],
    [ "PLASMA_sposv", "group__float_ga113c09b4a9f41fc4c19358a52477d685.html#ga113c09b4a9f41fc4c19358a52477d685", null ],
    [ "PLASMA_spotrf", "group__float_ga3ada27ebefe8e378bc6f9d25ab72d217.html#ga3ada27ebefe8e378bc6f9d25ab72d217", null ],
    [ "PLASMA_spotri", "group__float_gaf35cf8d73bf326a683f4be4943ef9b38.html#gaf35cf8d73bf326a683f4be4943ef9b38", null ],
    [ "PLASMA_spotrs", "group__float_gab813bd6d81c21feae7ce6553c9ba255a.html#gab813bd6d81c21feae7ce6553c9ba255a", null ],
    [ "PLASMA_ssyev", "group__float_ga92b57475b852b71b42bc39cd0d1ec356.html#ga92b57475b852b71b42bc39cd0d1ec356", null ],
    [ "PLASMA_ssyevd", "group__float_ga71305bb114c063946ddd9003bea058bf.html#ga71305bb114c063946ddd9003bea058bf", null ],
    [ "PLASMA_ssyevr", "group__float_ga850dfaa20a85559bd1ef0042e4218ecd.html#ga850dfaa20a85559bd1ef0042e4218ecd", null ],
    [ "PLASMA_ssygst", "group__float_ga66b77c0de44f80760c4184756250e75e.html#ga66b77c0de44f80760c4184756250e75e", null ],
    [ "PLASMA_ssygv", "group__float_gaa5deb8e85d037eff767d9a9e5e99fad9.html#gaa5deb8e85d037eff767d9a9e5e99fad9", null ],
    [ "PLASMA_ssygvd", "group__float_ga366bd2466847e2b9f29bd39a9d699fb9.html#ga366bd2466847e2b9f29bd39a9d699fb9", null ],
    [ "PLASMA_ssymm", "group__float_gaaffcd386f207f3e3a3073a803e27e3f1.html#gaaffcd386f207f3e3a3073a803e27e3f1", null ],
    [ "PLASMA_ssyr2k", "group__float_gafac964a38a7c62696c3b95d35108ad9b.html#gafac964a38a7c62696c3b95d35108ad9b", null ],
    [ "PLASMA_ssyrk", "group__float_gae83f0347570d23dc62dd8b298eb14ad6.html#gae83f0347570d23dc62dd8b298eb14ad6", null ],
    [ "PLASMA_ssytrd", "group__float_gadfee26871dee9a24b201bc329fccd81b.html#gadfee26871dee9a24b201bc329fccd81b", null ],
    [ "PLASMA_sTile_to_Lapack", "group__float_gacfc6859eb0da6e5c246a70178b5567be.html#gacfc6859eb0da6e5c246a70178b5567be", null ],
    [ "PLASMA_strmm", "group__float_gabbc2cf7c018815bd2c1ce8a6623b2813.html#gabbc2cf7c018815bd2c1ce8a6623b2813", null ],
    [ "PLASMA_strsm", "group__float_ga572e80d04d4e9701bf3dd73d1f96d54c.html#ga572e80d04d4e9701bf3dd73d1f96d54c", null ],
    [ "PLASMA_strsmpl", "group__float_ga245da4f8540c426fde27a50eff39b64a.html#ga245da4f8540c426fde27a50eff39b64a", null ],
    [ "PLASMA_strsmrv", "group__float_ga7713151eac0c0ff54c5a6aac1957b5e0.html#ga7713151eac0c0ff54c5a6aac1957b5e0", null ],
    [ "PLASMA_strtri", "group__float_gaaf0df7b8ff03a270a25da71b9f133abb.html#gaaf0df7b8ff03a270a25da71b9f133abb", null ]
];
